hedaro
======

.. image:: https://img.shields.io/pypi/v/hedaro.svg
    :target: https://pypi.python.org/pypi/hedaro
    :alt: Latest PyPI version

.. image:: https://api.travis-ci.org/hedaro-project/hedaro.png
   :target: https://travis-ci.org/github/hedaro-project/hedaro
   :alt: Latest Travis CI build status

A pentesting library for Python

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`hedaro` was written by `David Rojas <david@hedaro.com>`_.
